
#####################################################################
#
# ESPREM Client Init
#
# Project   : PYESPREMCLIENT
# Author(s) : Zafar Iqbal < zaf@sparc.gr >
# Copyright : (C) 2021 SPARC PC < https://sparc.space/ >
#
# All rights reserved. No warranty, explicit or implicit, provided.
# SPARC PC is and remains the owner of all titles, rights
# and interests in the Software.
#
#####################################################################

__version__ = "0.7.181100"

def test7( ) :
    return( 7 )

def get_version( ) :
    return __version__ 

    